@@ -10,7 +10,9 @@ dynamic_tenant_needs_sync = Signal()
 dynamic_tenant_needs_sync.__doc__ = "Sent when a schema from a dynamic tenant needs to be synced"
 
 dynamic_tenant_post_sync = Signal()
-dynamic_tenant_post_sync.__doc__ = "Sent after a tenant has been saved, its schema created and synced"
+dynamic_tenant_post_sync.__doc__ = (
+    "Sent after a tenant has been saved, its schema created and synced"
+)
 
 dynamic_tenant_pre_drop = Signal()
 dynamic_tenant_pre_drop.__doc__ = "Sent when a schema from a dynamic tenant is about to be dropped"
@@ -18,8 +20,11 @@ dynamic_tenant_pre_drop.__doc__ = "Sent when a schema from a dynamic tenant is a
 
 @receiver(pre_delete)
 def tenant_delete_callback(sender, instance, **kwargs):
-    if not isinstance(instance, get_tenant_model()):
+    TenantModel = get_tenant_model()
+    if TenantModel is None:
+        return
+    if not isinstance(instance, TenantModel):
         return
     if instance.auto_drop_schema and schema_exists(instance.schema_name):
-        dynamic_tenant_pre_drop.send(sender=get_tenant_model(), tenant=instance.serializable_fields())
+        dynamic_tenant_pre_drop.send(sender=TenantModel, tenant=instance.serializable_fields())
         instance.drop_schema()
