@@ -1,3 +1,5 @@
+import unittest
+
 from django.core import management
 from django.db import connections
 from django.test import TransactionTestCase
@@ -15,10 +17,14 @@ class ExecutorsTestCase(TransactionTestCase):
 
     @classmethod
     def setUpClass(cls):
+        if TenantModel is None:
+            raise unittest.SkipTest("Dynamic tenants are not being used")
         for i in range(10):
             tenant = TenantModel(schema_name=f"tenant{i + 1}")
             tenant.save(verbosity=0)
-            DomainModel.objects.create(tenant=tenant, domain=f"tenant{i + 1}.localhost", is_primary=True)
+            DomainModel.objects.create(
+                tenant=tenant, domain=f"tenant{i + 1}.localhost", is_primary=True
+            )
 
     @classmethod
     def tearDownClass(cls):
