@@ -1,3 +1,5 @@
+import unittest
+
 from django.test import RequestFactory, TestCase
 
 from django_pgschemas.middleware import TenantMiddleware
@@ -12,6 +14,12 @@ class TenantMiddlewareRedirectionTestCase(TestCase):
     Tests TenantMiddlewareRedirection.
     """
 
+    @classmethod
+    def setUpClass(cls):
+        if TenantModel is None:
+            raise unittest.SkipTest("Dynamic tenants are not being used")
+        super().setUpClass()
+
     @classmethod
     def setUpTestData(cls):
         cls.factory = RequestFactory()
@@ -23,7 +31,10 @@ class TenantMiddlewareRedirectionTestCase(TestCase):
 
         DomainModel(domain="tenant1.localhost", tenant=tenant1).save()
         DomainModel(
-            domain="tenant1redirect.localhost", tenant=tenant1, is_primary=False, redirect_to_primary=True
+            domain="tenant1redirect.localhost",
+            tenant=tenant1,
+            is_primary=False,
+            redirect_to_primary=True,
         ).save()
         DomainModel(
             domain="everyone.localhost",
@@ -35,7 +46,10 @@ class TenantMiddlewareRedirectionTestCase(TestCase):
 
         DomainModel(domain="everyone.localhost", folder="tenant2", tenant=tenant2).save()
         DomainModel(
-            domain="tenant2redirect.localhost", tenant=tenant2, is_primary=False, redirect_to_primary=True
+            domain="tenant2redirect.localhost",
+            tenant=tenant2,
+            is_primary=False,
+            redirect_to_primary=True,
         ).save()
         DomainModel(
             domain="everyone.localhost",
@@ -59,7 +73,9 @@ class TenantMiddlewareRedirectionTestCase(TestCase):
         self.assertEqual(response["Location"], "//tenant1.localhost/some/random/url/")
 
     def test_folder_redirect_to_primary_domain(self):
-        request = self.factory.get("/tenant1redirect/some/random/url/", HTTP_HOST="everyone.localhost")
+        request = self.factory.get(
+            "/tenant1redirect/some/random/url/", HTTP_HOST="everyone.localhost"
+        )
         response = self.middleware(request)
         self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, "//tenant1.localhost/some/random/url/")
@@ -73,7 +89,9 @@ class TenantMiddlewareRedirectionTestCase(TestCase):
         self.assertEqual(response["Location"], "//everyone.localhost/tenant2/some/random/url/")
 
     def test_folder_redirect_to_primary_folder(self):
-        request = self.factory.get("/tenant2redirect/some/random/url/", HTTP_HOST="everyone.localhost")
+        request = self.factory.get(
+            "/tenant2redirect/some/random/url/", HTTP_HOST="everyone.localhost"
+        )
         response = self.middleware(request)
         self.assertEqual(response.status_code, 301)
         self.assertEqual(response.url, "//everyone.localhost/tenant2/some/random/url/")
