@@ -17,8 +17,8 @@ DomainModel = get_domain_model()
 BlogEntry = apps.get_model("app_blog.BlogEntry")
 Catalog = apps.get_model("shared_public.Catalog")
 MainData = apps.get_model("app_main.MainData")
-TenantData = apps.get_model("app_tenants.TenantData")
 User = apps.get_model("shared_common.User")
+TenantData = apps.get_model("app_tenants.TenantData") if "default" in settings.TENANTS else None
 
 
 class ControlledException(Exception):
@@ -30,6 +30,10 @@ class TenantAutomaticTestCase(TestCase):
     Tests tenant automatic operations.
     """
 
+    def setUp(self):
+        if TenantModel is None:
+            self.skipTest("Dynamic tenants are not being used")
+
     def test_new_creation_deletion(self):
         "Tests automatic creation/deletion for new tenant's save/delete"
         self.assertFalse(schema_exists("tenant1"))
@@ -98,8 +102,9 @@ class TenantTestCase(TestCase):
 
     @classmethod
     def setUpClass(cls):
-        tenant = TenantModel(schema_name="tenant")
-        tenant.save(verbosity=0)
+        if TenantModel is not None:
+            tenant = TenantModel(schema_name="tenant")
+            tenant.save(verbosity=0)
         catalog = Catalog.objects.create()
         Catalog.objects.create()
         with SchemaDescriptor.create(schema_name="www"):
@@ -112,11 +117,12 @@ class TenantTestCase(TestCase):
             user.set_password("weakpassword")
             user.save()
             BlogEntry.objects.create(user=user)
-        with TenantModel.objects.first():
-            user = User.objects.create(email="tenant@localhost", display_name="Tenant User")
-            user.set_password("weakpassword")
-            user.save()
-            TenantData.objects.create(user=user, catalog=catalog)
+        if TenantModel is not None:
+            with TenantModel.objects.first():
+                user = User.objects.create(email="tenant@localhost", display_name="Tenant User")
+                user.set_password("weakpassword")
+                user.save()
+                TenantData.objects.create(user=user, catalog=catalog)
         activate_public()
         super().setUpClass()
 
@@ -127,7 +133,8 @@ class TenantTestCase(TestCase):
             if key == "default":
                 continue
             drop_schema(key)
-        drop_schema("tenant")
+        if TenantModel is not None:
+            drop_schema("tenant")
         call_command("migrateschema", verbosity=0)
 
     @contextmanager
@@ -151,8 +158,9 @@ class TenantTestCase(TestCase):
             list(MainData.objects.all())
         with self.assertRaises(ProgrammingError):
             list(BlogEntry.objects.all())
-        with self.assertRaises(ProgrammingError):
-            list(TenantData.objects.all())
+        if TenantData is not None:
+            with self.assertRaises(ProgrammingError):
+                list(TenantData.objects.all())
 
     def test_synced_main_apps(self):
         with SchemaDescriptor.create(schema_name="www"):
@@ -163,8 +171,9 @@ class TenantTestCase(TestCase):
             # Not expected synced apps
             with self.assertRaises(ProgrammingError):
                 list(BlogEntry.objects.all())
-            with self.assertRaises(ProgrammingError):
-                list(TenantData.objects.all())
+            if TenantData is not None:
+                with self.assertRaises(ProgrammingError):
+                    list(TenantData.objects.all())
 
     def test_synced_blog_apps(self):
         with SchemaDescriptor.create(schema_name="blog"):
@@ -178,10 +187,13 @@ class TenantTestCase(TestCase):
             # Not expected synced apps
             with self.assertRaises(ProgrammingError):
                 list(MainData.objects.all())
-            with self.assertRaises(ProgrammingError):
-                list(TenantData.objects.all())
+            if TenantData is not None:
+                with self.assertRaises(ProgrammingError):
+                    list(TenantData.objects.all())
 
     def test_synced_tenant_apps(self):
+        if TenantModel is None:
+            self.skipTest("Dynamic tenants are not being used")
         with TenantModel.objects.first():
             # Expected synced apps
             self.assertEqual(2, Catalog.objects.count())
@@ -189,9 +201,13 @@ class TenantTestCase(TestCase):
             self.assertEqual(1, User.objects.count())
             # Direct and reverse relations
             self.assertEqual(User.objects.first(), TenantData.objects.first().user)
-            self.assertEqual(User.objects.first().tenant_objects.first(), TenantData.objects.first())
+            self.assertEqual(
+                User.objects.first().tenant_objects.first(), TenantData.objects.first()
+            )
             self.assertEqual(Catalog.objects.first(), TenantData.objects.first().catalog)
-            self.assertEqual(Catalog.objects.first().tenant_objects.first(), TenantData.objects.first())
+            self.assertEqual(
+                Catalog.objects.first().tenant_objects.first(), TenantData.objects.first()
+            )
             # Not expected synced apps
             with self.assertRaises(ProgrammingError):
                 list(MainData.objects.all())
@@ -207,10 +223,17 @@ class TenantTestCase(TestCase):
             self.assertTrue(authenticate(email="blog@localhost", password="weakpassword"))  # good
             self.assertFalse(authenticate(email="main@localhost", password="weakpassword"))  # bad
             self.assertFalse(authenticate(email="tenant@localhost", password="weakpassword"))  # bad
-        with TenantModel.objects.first():
-            self.assertTrue(authenticate(email="tenant@localhost", password="weakpassword"))  # good
-            self.assertFalse(authenticate(email="main@localhost", password="weakpassword"))  # bad
-            self.assertFalse(authenticate(email="blog@localhost", password="weakpassword"))  # bad
+        if TenantModel is not None:
+            with TenantModel.objects.first():
+                self.assertTrue(
+                    authenticate(email="tenant@localhost", password="weakpassword")
+                )  # good
+                self.assertFalse(
+                    authenticate(email="main@localhost", password="weakpassword")
+                )  # bad
+                self.assertFalse(
+                    authenticate(email="blog@localhost", password="weakpassword")
+                )  # bad
         # Switching to public schema
         activate_public()
         with self.assertRaises(ProgrammingError):
@@ -222,13 +245,19 @@ class DomainTestCase(TestCase):
     Tests domain operations.
     """
 
+    def setUp(self):
+        if TenantModel is None:
+            self.skipTest("Dynamic tenants are not being used")
+
     def test_primary_domain(self):
         tenant1 = TenantModel(schema_name="tenant1")
         tenant2 = TenantModel(schema_name="tenant2")
         tenant1.save(verbosity=0)
         tenant2.save(verbosity=0)
         domain1 = DomainModel.objects.create(domain="tenant1.localhost", tenant=tenant1)
-        DomainModel.objects.create(domain="tenant1-other.localhost", tenant=tenant1, is_primary=False)
+        DomainModel.objects.create(
+            domain="tenant1-other.localhost", tenant=tenant1, is_primary=False
+        )
         self.assertEqual(tenant1.get_primary_domain(), domain1)
         self.assertEqual(tenant2.get_primary_domain(), None)
         for tenant in TenantModel.objects.all():
@@ -238,7 +267,9 @@ class DomainTestCase(TestCase):
         tenant = TenantModel(schema_name="tenant")
         tenant.save(verbosity=0)
         domain1 = DomainModel.objects.create(domain="tenant.localhost", tenant=tenant)
-        domain2 = DomainModel.objects.create(domain="everyone.localhost", folder="tenant", tenant=tenant)
+        domain2 = DomainModel.objects.create(
+            domain="everyone.localhost", folder="tenant", tenant=tenant
+        )
         self.assertEqual(str(domain1), "tenant.localhost")
         self.assertEqual(str(domain2), "everyone.localhost/tenant")
         tenant.delete(force_drop=True)
@@ -247,19 +278,27 @@ class DomainTestCase(TestCase):
         tenant = TenantModel(schema_name="tenant")
         tenant.save(verbosity=0)
         subdomain = DomainModel.objects.create(domain="tenant.localhost", tenant=tenant)
-        subfolder = DomainModel.objects.create(domain="everyone.localhost", folder="tenant", tenant=tenant)
+        subfolder = DomainModel.objects.create(
+            domain="everyone.localhost", folder="tenant", tenant=tenant
+        )
         self.assertEqual(subdomain.absolute_url(""), "//tenant.localhost/")
         self.assertEqual(subdomain.absolute_url("/some/path/"), "//tenant.localhost/some/path/")
         self.assertEqual(subdomain.absolute_url("some/path"), "//tenant.localhost/some/path")
         self.assertEqual(subfolder.absolute_url(""), "//everyone.localhost/tenant/")
-        self.assertEqual(subfolder.absolute_url("/some/path/"), "//everyone.localhost/tenant/some/path/")
-        self.assertEqual(subfolder.absolute_url("some/path"), "//everyone.localhost/tenant/some/path")
+        self.assertEqual(
+            subfolder.absolute_url("/some/path/"), "//everyone.localhost/tenant/some/path/"
+        )
+        self.assertEqual(
+            subfolder.absolute_url("some/path"), "//everyone.localhost/tenant/some/path"
+        )
         tenant.delete(force_drop=True)
 
     def test_domain_redirect_save(self):
         tenant = TenantModel(schema_name="tenant")
         tenant.save(verbosity=0)
-        domain = DomainModel.objects.create(domain="tenant.localhost", tenant=tenant, redirect_to_primary=True)
+        domain = DomainModel.objects.create(
+            domain="tenant.localhost", tenant=tenant, redirect_to_primary=True
+        )
         self.assertTrue(domain.is_primary)
         self.assertFalse(domain.redirect_to_primary)
         tenant.delete(force_drop=True)
